from django.db import models
from django.utils.translation import ugettext_lazy as _
from cms.models.pluginmodel import CMSPlugin


class TwitterRecentEntries(CMSPlugin):
    title = models.CharField(_('title'), max_length=75, blank=True)
    twitter_user = models.CharField(_('twitter user'), max_length=75)
    count = models.PositiveSmallIntegerField(_('count'), default=3,
                                             help_text=_('Number of entries to display'))
    link_hint = models.CharField(_('link hint'), max_length=75, blank=True,
                                 help_text=_('Deprecated: no longer used by Twitter widgets.'))
    twitter_id = models.CharField(_('twitter id'), max_length=75,
                                 help_text=_(u'See https://twitter.com/settings/widgets on how to obtain one'))

    def __unicode__(self):
        return self.title


class TwitterSearch(CMSPlugin):
    title = models.CharField(_('title'), max_length=75, blank=True)
    query = models.CharField(_('query'), max_length=200, blank=True, default='',
                             help_text=_('Deprecated: no longer used by Twitter widgets. Define one when creating widgets.'))
    count = models.PositiveSmallIntegerField(_('count'), default=3,
                                             help_text=_('Number of entries to display'))
    twitter_id = models.CharField(_('twitter id'), max_length=75,
                                 help_text=_(u'See https://twitter.com/settings/widgets on how to obtain one'))

    def __unicode__(self):
        return self.title



from django.utils.translation import ugettext_lazy as _
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .models import TwitterRecentEntries, TwitterSearch


class TwitterRecentEntriesPlugin(CMSPluginBase):
    model = TwitterRecentEntries
    name = _("Twitter")
    render_template = "cms/plugins/twitter_timeline.html"
    
    def render(self, context, instance, placeholder):
        context.update({
            'object': instance,
        })
        return context
    
plugin_pool.register_plugin(TwitterRecentEntriesPlugin)


class TwitterSearchPlugin(CMSPluginBase):
    model = TwitterSearch
    name = _("Twitter Search")
    render_template = "cms/plugins/twitter_search_widget.html"
    admin_preview = False
    
    def render(self, context, instance, placeholder):
        context.update({
            'object': instance,
        })
        return context
plugin_pool.register_plugin(TwitterSearchPlugin)


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0013_auto_20151112_1654'),
    ]

    operations = [
        migrations.CreateModel(
            name='TwitterRecentEntries',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('title', models.CharField(max_length=75, verbose_name='title', blank=True)),
                ('twitter_user', models.CharField(max_length=75, verbose_name='twitter user')),
                ('count', models.PositiveSmallIntegerField(default=3, help_text='Number of entries to display', verbose_name='count')),
                ('link_hint', models.CharField(help_text='Deprecated: no longer used by Twitter widgets.', max_length=75, verbose_name='link hint', blank=True)),
                ('twitter_id', models.CharField(help_text='See https://twitter.com/settings/widgets on how to obtain one', max_length=75, verbose_name='twitter id')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='TwitterSearch',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('title', models.CharField(max_length=75, verbose_name='title', blank=True)),
                ('query', models.CharField(default=b'', help_text='Deprecated: no longer used by Twitter widgets. Define one when creating widgets.', max_length=200, verbose_name='query', blank=True)),
                ('count', models.PositiveSmallIntegerField(default=3, help_text='Number of entries to display', verbose_name='count')),
                ('twitter_id', models.CharField(help_text='See https://twitter.com/settings/widgets on how to obtain one', max_length=75, verbose_name='twitter id')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup
from djangocms_twitter import __version__


CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Communications',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content :: Message Boards',
    "Programming Language :: Python :: 2.6",
    "Programming Language :: Python :: 2.7",
]

setup(
    name='djangocms-twitter',
    version=__version__,
    description='Twitter plugin for django CMS',
    author='Nephila s.a.s.',
    author_email='web@nephila.it',
    url='https://github.com/nephila/djangocms_twitter',
    packages=['djangocms_twitter', 'djangocms_twitter.migrations'],
    install_requires=[
        'django-cms>=3.0'
    ],
    license='LICENSE.txt',
    platforms=['OS Independent'],
    classifiers=CLASSIFIERS,
    long_description=open('README.rst').read(),
    include_package_data=True,
    zip_safe=False
)